@@ -13,11 +13,11 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import LogTypeType, OpenSearchPartitionInstanceTypeType
+from .literals import EngineTypeType, LogTypeType, OpenSearchPartitionInstanceTypeType
 from .type_defs import (
     AcceptInboundConnectionResponseTypeDef,
     AdvancedSecurityOptionsInputTypeDef,
@@ -87,7 +87,7 @@ __all__ = ("OpenSearchServiceClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -109,7 +109,7 @@ class Exceptions:
 
 class OpenSearchServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html)
     """
 
@@ -128,15 +128,15 @@ class OpenSearchServiceClient(BaseClient):
         Allows the remote domain owner to accept an inbound cross-cluster connection
         request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.accept_inbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.accept_inbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#accept_inbound_connection)
         """
 
-    def add_tags(self, *, ARN: str, TagList: List["TagTypeDef"]) -> None:
+    def add_tags(self, *, ARN: str, TagList: Sequence["TagTypeDef"]) -> None:
         """
         Attaches tags to an existing domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#add_tags)
         """
 
@@ -146,7 +146,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Associates a package with an Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.associate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.associate_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#associate_package)
         """
 
@@ -154,7 +154,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#can_paginate)
         """
 
@@ -165,7 +165,7 @@ class OpenSearchServiceClient(BaseClient):
         Cancels a scheduled service software update for an Amazon OpenSearch Service
         domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.cancel_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.cancel_service_software_update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#cancel_service_software_update)
         """
 
@@ -182,17 +182,17 @@ class OpenSearchServiceClient(BaseClient):
         CognitoOptions: "CognitoOptionsTypeDef" = None,
         EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = None,
         NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = None,
-        AdvancedOptions: Dict[str, str] = None,
-        LogPublishingOptions: Dict[LogTypeType, "LogPublishingOptionTypeDef"] = None,
+        AdvancedOptions: Mapping[str, str] = None,
+        LogPublishingOptions: Mapping[LogTypeType, "LogPublishingOptionTypeDef"] = None,
         DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = None,
         AdvancedSecurityOptions: "AdvancedSecurityOptionsInputTypeDef" = None,
-        TagList: List["TagTypeDef"] = None,
+        TagList: Sequence["TagTypeDef"] = None,
         AutoTuneOptions: "AutoTuneOptionsInputTypeDef" = None
     ) -> CreateDomainResponseTypeDef:
         """
         Creates a new Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.create_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.create_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#create_domain)
         """
 
@@ -207,7 +207,7 @@ class OpenSearchServiceClient(BaseClient):
         Creates a new cross-cluster connection from a local OpenSearch domain to a
         remote OpenSearch domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.create_outbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.create_outbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#create_outbound_connection)
         """
 
@@ -222,7 +222,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Create a package for use with Amazon OpenSearch Service domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.create_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.create_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#create_package)
         """
 
@@ -230,7 +230,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Permanently deletes the specified domain and all of its data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.delete_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.delete_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_domain)
         """
 
@@ -241,7 +241,7 @@ class OpenSearchServiceClient(BaseClient):
         Allows the remote domain owner to delete an existing inbound cross-cluster
         connection.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.delete_inbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.delete_inbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_inbound_connection)
         """
 
@@ -252,7 +252,7 @@ class OpenSearchServiceClient(BaseClient):
         Allows the local domain owner to delete an existing outbound cross-cluster
         connection.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.delete_outbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.delete_outbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_outbound_connection)
         """
 
@@ -260,7 +260,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Deletes the package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.delete_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.delete_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_package)
         """
 
@@ -269,7 +269,7 @@ class OpenSearchServiceClient(BaseClient):
         Returns domain configuration information about the specified domain, including
         the domain ID, domain endpoint, and domain ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.describe_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domain)
         """
 
@@ -280,7 +280,7 @@ class OpenSearchServiceClient(BaseClient):
         Provides scheduled Auto-Tune action details for the domain, such as Auto-Tune
         action type, description, severity, and scheduled date.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_auto_tunes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_auto_tunes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domain_auto_tunes)
         """
 
@@ -289,30 +289,30 @@ class OpenSearchServiceClient(BaseClient):
         Provides cluster configuration information about the specified domain, such as
         the state, creation date, update version, and update date for cluster options.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domain_config)
         """
 
-    def describe_domains(self, *, DomainNames: List[str]) -> DescribeDomainsResponseTypeDef:
+    def describe_domains(self, *, DomainNames: Sequence[str]) -> DescribeDomainsResponseTypeDef:
         """
         Returns domain configuration information about the specified domains, including
         the domain ID, domain endpoint, and domain ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.describe_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_domains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domains)
         """
 
     def describe_inbound_connections(
         self,
         *,
-        Filters: List["FilterTypeDef"] = None,
+        Filters: Sequence["FilterTypeDef"] = None,
         MaxResults: int = None,
         NextToken: str = None
     ) -> DescribeInboundConnectionsResponseTypeDef:
         """
         Lists all the inbound cross-cluster connections for a remote domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.describe_inbound_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_inbound_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_inbound_connections)
         """
 
@@ -327,35 +327,35 @@ class OpenSearchServiceClient(BaseClient):
         Describe the limits for a given instance type and OpenSearch or Elasticsearch
         version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.describe_instance_type_limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_instance_type_limits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_instance_type_limits)
         """
 
     def describe_outbound_connections(
         self,
         *,
-        Filters: List["FilterTypeDef"] = None,
+        Filters: Sequence["FilterTypeDef"] = None,
         MaxResults: int = None,
         NextToken: str = None
     ) -> DescribeOutboundConnectionsResponseTypeDef:
         """
         Lists all the outbound cross-cluster connections for a local domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.describe_outbound_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_outbound_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_outbound_connections)
         """
 
     def describe_packages(
         self,
         *,
-        Filters: List["DescribePackagesFilterTypeDef"] = None,
+        Filters: Sequence["DescribePackagesFilterTypeDef"] = None,
         MaxResults: int = None,
         NextToken: str = None
     ) -> DescribePackagesResponseTypeDef:
         """
         Describes all packages available to Amazon OpenSearch Service domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.describe_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_packages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_packages)
         """
 
@@ -369,7 +369,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Lists available reserved OpenSearch instance offerings.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instance_offerings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instance_offerings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_reserved_instance_offerings)
         """
 
@@ -379,7 +379,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Returns information about reserved OpenSearch instances for this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_reserved_instances)
         """
 
@@ -389,21 +389,21 @@ class OpenSearchServiceClient(BaseClient):
         """
         Dissociates a package from the Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.dissociate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.dissociate_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#dissociate_package)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#generate_presigned_url)
         """
 
@@ -413,7 +413,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Returns a list of upgrade-compatible versions of OpenSearch/Elasticsearch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.get_compatible_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.get_compatible_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_compatible_versions)
         """
 
@@ -424,7 +424,7 @@ class OpenSearchServiceClient(BaseClient):
         Returns a list of package versions, along with their creation time and commit
         message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.get_package_version_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.get_package_version_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_package_version_history)
         """
 
@@ -434,7 +434,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Retrieves the complete history of the last 10 upgrades performed on the domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_upgrade_history)
         """
 
@@ -443,15 +443,17 @@ class OpenSearchServiceClient(BaseClient):
         Retrieves the latest status of the last upgrade or upgrade eligibility check
         performed on the domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_upgrade_status)
         """
 
-    def list_domain_names(self) -> ListDomainNamesResponseTypeDef:
+    def list_domain_names(
+        self, *, EngineType: EngineTypeType = None
+    ) -> ListDomainNamesResponseTypeDef:
         """
         Returns the names of all domains owned by the current user's account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.list_domain_names)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_domain_names)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_domain_names)
         """
 
@@ -461,7 +463,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Lists all Amazon OpenSearch Service domains associated with the package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.list_domains_for_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_domains_for_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_domains_for_package)
         """
 
@@ -479,7 +481,7 @@ class OpenSearchServiceClient(BaseClient):
         client.list_instance_type_details( EngineVersion='string', DomainName='string',
         MaxResults=123, NextToken='stri...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.list_instance_type_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_instance_type_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_instance_type_details)
         """
 
@@ -489,7 +491,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Lists all packages associated with the Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.list_packages_for_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_packages_for_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_packages_for_domain)
         """
 
@@ -497,7 +499,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Returns all tags for the given domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.list_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_tags)
         """
 
@@ -507,7 +509,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         List all supported versions of OpenSearch and Elasticsearch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.list_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_versions)
         """
 
@@ -517,7 +519,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Allows you to purchase reserved OpenSearch instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.purchase_reserved_instance_offering)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.purchase_reserved_instance_offering)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#purchase_reserved_instance_offering)
         """
 
@@ -528,15 +530,15 @@ class OpenSearchServiceClient(BaseClient):
         Allows the remote domain owner to reject an inbound cross-cluster connection
         request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.reject_inbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.reject_inbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#reject_inbound_connection)
         """
 
-    def remove_tags(self, *, ARN: str, TagKeys: List[str]) -> None:
+    def remove_tags(self, *, ARN: str, TagKeys: Sequence[str]) -> None:
         """
         Removes the specified set of tags from the given domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.remove_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#remove_tags)
         """
 
@@ -546,7 +548,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Schedules a service software update for an Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.start_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.start_service_software_update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#start_service_software_update)
         """
 
@@ -559,9 +561,9 @@ class OpenSearchServiceClient(BaseClient):
         SnapshotOptions: "SnapshotOptionsTypeDef" = None,
         VPCOptions: "VPCOptionsTypeDef" = None,
         CognitoOptions: "CognitoOptionsTypeDef" = None,
-        AdvancedOptions: Dict[str, str] = None,
+        AdvancedOptions: Mapping[str, str] = None,
         AccessPolicies: str = None,
-        LogPublishingOptions: Dict[LogTypeType, "LogPublishingOptionTypeDef"] = None,
+        LogPublishingOptions: Mapping[LogTypeType, "LogPublishingOptionTypeDef"] = None,
         EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = None,
         DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = None,
         NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = None,
@@ -572,7 +574,7 @@ class OpenSearchServiceClient(BaseClient):
         Modifies the cluster configuration of the specified domain, such as setting the
         instance type and the number of instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.update_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.update_domain_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#update_domain_config)
         """
 
@@ -587,7 +589,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Updates a package for use with Amazon OpenSearch Service domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.update_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.update_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#update_package)
         """
 
@@ -597,12 +599,12 @@ class OpenSearchServiceClient(BaseClient):
         DomainName: str,
         TargetVersion: str,
         PerformCheckOnly: bool = None,
-        AdvancedOptions: Dict[str, str] = None
+        AdvancedOptions: Mapping[str, str] = None
     ) -> UpgradeDomainResponseTypeDef:
         """
         Allows you to either upgrade your domain or perform an upgrade eligibility check
         to a compatible version of OpenSearch or Elasticsearch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/opensearch.html#OpenSearchService.Client.upgrade_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.upgrade_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#upgrade_domain)
         """
